summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-07-30 23:11:33 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-07-30 23:11:33 +0000
commit5aaffadfcad8e2599801c06c26287875a2c8374a (patch)
tree5a3c7edae44deb233701c00a2a69e4b9cc5e49b1
parent96422484232cc296b893a638d92b1f1fa9b148fb (diff)
downloadATCD-5aaffadfcad8e2599801c06c26287875a2c8374a.tar.gz
*** empty log message ***
-rw-r--r--ace/Reactor.h10
-rw-r--r--ace/SOCK_Dgram.h3
2 files changed, 7 insertions, 6 deletions
diff --git a/ace/SOCK_Dgram.h b/ace/SOCK_Dgram.h
index b2969afb03f..96437cfa210 100644
--- a/ace/SOCK_Dgram.h
+++ b/ace/SOCK_Dgram.h
@@ -63,7 +63,8 @@ public:
// buffer to read. This method determines how much data is in the
// socket, allocates a buffer of this size, reads in the data, and
// returns the number of bytes read. The caller is responsible for
- // deleting the member in the <iov_base> field of <io_vec>.
+ // deleting the member in the <iov_base> field of <io_vec> using the
+ // ``delete []'' syntax.
ssize_t send (const iovec iov[],
size_t n,
diff --git a/ace/Reactor.h b/ace/Reactor.h
index a6e0614047c..ad3c30280ec 100644
--- a/ace/Reactor.h
+++ b/ace/Reactor.h
@@ -473,12 +473,12 @@ public:
// = Timer management.
virtual long schedule_timer (ACE_Event_Handler *,
const void *arg,
- const ACE_Time_Value &delta,
+ const ACE_Time_Value &delta_time,
const ACE_Time_Value &interval = ACE_Time_Value::zero);
// Schedule an <event_handler> that will expire after <delay> amount
// of time. If it expires then <arg> is passed in as the value to
// the <event_handler>'s <handle_timeout> callback method. If
// <interval> is != to <ACE_Time_Value::zero> then it is used to
// reschedule the <event_handler> automatically. This method
// returns a <timer_id> that uniquely identifies the <event_handler>
// in an internal list. This <timer_id> can be used to cancel an
@@ -473,12 +473,12 @@ public:
const ACE_Time_Value &interval = ACE_Time_Value::zero);
- // Schedule an <event_handler> that will expire after <delay> amount
- // of time. If it expires then <arg> is passed in as the value to
- // the <event_handler>'s <handle_timeout> callback method. If
- // <interval> is != to <ACE_Time_Value::zero> then it is used to
+ // Schedule an <event_handler> that will expire after <delta_time>
+ // amount of time. If it expires then <arg> is passed in as the
+ // value to the <event_handler>'s <handle_timeout> callback method.
+ // If <interval> is != to <ACE_Time_Value::zero> then it is used to
// reschedule the <event_handler> automatically. This method
// returns a <timer_id> that uniquely identifies the <event_handler>